summaryrefslogtreecommitdiff
path: root/innobase/include/lock0lock.h
diff options
context:
space:
mode:
Diffstat (limited to 'innobase/include/lock0lock.h')
-rw-r--r--innobase/include/lock0lock.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/innobase/include/lock0lock.h b/innobase/include/lock0lock.h
index 103d28cd130..9ccea5ad7a4 100644
--- a/innobase/include/lock0lock.h
+++ b/innobase/include/lock0lock.h
@@ -19,7 +19,11 @@ Created 5/7/1996 Heikki Tuuri
#include "read0types.h"
#include "hash0hash.h"
+#ifdef UNIV_DEBUG
extern ibool lock_print_waits;
+#endif /* UNIV_DEBUG */
+/* Buffer for storing information about the most recent deadlock error */
+extern FILE* lock_latest_err_file;
/*************************************************************************
Gets the size of a lock struct. */
@@ -453,6 +457,7 @@ lock_check_trx_id_sanity(
dict_index_t* index, /* in: clustered index */
ibool has_kernel_mutex);/* in: TRUE if the caller owns the
kernel mutex */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates the lock queue on a single record. */
@@ -462,14 +467,14 @@ lock_rec_queue_validate(
/* out: TRUE if ok */
rec_t* rec, /* in: record to look at */
dict_index_t* index); /* in: index, or NULL if not known */
+#endif /* UNIV_DEBUG */
/*************************************************************************
Prints info of a table lock. */
void
lock_table_print(
/*=============*/
- char* buf, /* in/out: buffer where to print, must be at least
- 500 bytes */
+ FILE* file, /* in: file where to print */
lock_t* lock); /* in: table type lock */
/*************************************************************************
Prints info of a record lock. */
@@ -477,8 +482,7 @@ Prints info of a record lock. */
void
lock_rec_print(
/*===========*/
- char* buf, /* in/out: buffer where to print, must be at least
- 500 bytes */
+ FILE* file, /* in: file where to print */
lock_t* lock); /* in: record type lock */
/*************************************************************************
Prints info of locks for all transactions. */
@@ -486,8 +490,8 @@ Prints info of locks for all transactions. */
void
lock_print_info(
/*============*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end);/* in: buffer end */
+ FILE* file); /* in: file where to print */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates the lock queue on a table. */
@@ -512,6 +516,7 @@ ibool
lock_validate(void);
/*===============*/
/* out: TRUE if ok */
+#endif /* UNIV_DEBUG */
/* The lock system */
extern lock_sys_t* lock_sys;